pm4py.algo.analysis.extended\_marking\_equation package
=======================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.analysis.extended_marking_equation.variants

Submodules
----------

pm4py.algo.analysis.extended\_marking\_equation.algorithm module
----------------------------------------------------------------

.. automodule:: pm4py.algo.analysis.extended_marking_equation.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.analysis.extended_marking_equation
   :members:
   :undoc-members:
   :show-inheritance:
